@@ -1,4 +1,4 @@
-use crate::{spawn, Address, Context, Message, Result, Route};
+use crate::{Address, Context, Message, Result, Route};
 use core::time::Duration;
 
 /// Send a delayed event to a worker
@@ -12,7 +12,7 @@ pub(crate) struct DelayedEvent<M: Message> {
 impl<M: Message> DelayedEvent<M> {
     /// Create a new 100ms delayed message event
     pub(crate) async fn new(ctx: &Context, route: Route, msg: M) -> Result<Self> {
-        let child_ctx = ctx.new_context(Address::random(0)).await?;
+        let child_ctx = ctx.new_context(Address::random_local()).await?;
 
         debug!(
             "Creating a delayed event with address '{}'",
@@ -43,7 +43,7 @@ impl<M: Message> DelayedEvent<M> {
     /// Run this delayed event
     pub(crate) fn spawn(self) {
         let Self { route, ctx, d, msg } = self;
-        spawn(async move {
+        ockam_node::spawn(async move {
             ctx.sleep(d).await;
             if let Err(e) = ctx.send(route, msg).await {
                 error!("Failed to send delayed message: {}", e);
