@@ -1,10 +1,14 @@
 #![deny(missing_docs)]
 #![allow(missing_docs)] // Contents are self describing for now.
 
-/// An enumeration describing some of the error types emitted by this library.
+use ockam_core::{
+    errcode::{Kind, Origin},
+    Error,
+};
+
+/// An enumeration of different error types emitted by this library.
 ///
 /// Most user code should use [`crate::Error`] instead.
-// FIXME: use updated ockam_core::Error...
 #[derive(Clone, Copy, Debug)]
 pub enum OckamError {
     BareError = 1,
@@ -26,23 +30,28 @@ pub enum OckamError {
     InvalidParameter,
     SecureChannelVerificationFailed,
     SecureChannelCannotBeAuthenticated,
-    NoSuchProtocol, // 20
+    NoSuchProtocol,
     SystemAddressNotBound,
     SystemInvalidConfiguration,
 }
 
-impl OckamError {
-    /// Integer code associated with the error domain.
-    pub const DOMAIN_CODE: u32 = 10_000;
-    /// Descriptive name for the error domain.
-    pub const DOMAIN_NAME: &'static str = "OCKAM";
+impl ockam_core::compat::error::Error for OckamError {}
+impl core::fmt::Display for OckamError {
+    fn fmt(&self, f: &mut core::fmt::Formatter<'_>) -> core::fmt::Result {
+        core::fmt::Debug::fmt(self, f)
+    }
 }
 
-impl From<OckamError> for ockam_core::Error {
-    fn from(e: OckamError) -> ockam_core::Error {
-        ockam_core::Error::new(
-            OckamError::DOMAIN_CODE + (e as u32),
-            ockam_core::compat::format!("{}::{:?}", module_path!(), e),
-        )
+impl From<OckamError> for Error {
+    #[track_caller]
+    fn from(err: OckamError) -> Error {
+        use OckamError::*;
+        // TODO: improve this mapping
+        let kind = match err {
+            SystemAddressNotBound | SystemInvalidConfiguration | InvalidParameter => Kind::Misuse,
+            _ => Kind::Protocol,
+        };
+
+        Error::new(Origin::Ockam, kind, err)
     }
 }
